==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Your_Account/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_YES","Da");
define("_NO","Ne");
define("_OPTIONAL","(po elji)");
define("_REQUIRED","(obvezno)");
define("_SAVECHANGES","Shrani spremembe");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","Brez komentarja");
define("_NESTED","Vgnezdeno");
define("_FLAT","Plosko");
define("_THREAD","Nit");
define("_OLDEST","Stareje");
define("_NEWEST","Noveje");
define("_HIGHEST","Z najvijim rezultatom");
define("_ERRORINVEMAIL","NAPAKA: Nepravilen E-mail");
define("_ERROREMAILSPACES","NAPAKA: E-mail naslov ne vsebuje razmakov");
define("_ERRORINVNICK","NAPAKA: Nepravilen nadimek");
define("_NICK2LONG","Nadimek je predolg. Biti mora manji od 25 znakov");
define("_NAMERESERVED","NAPAKA: To ime je rezervirano");
define("_NICKNOSPACES","NAPAKA: Nadimek ne sme vsebovati razmakov");
define("_NICKTAKEN","NAPAKA: Nadimek je e zaseden");
define("_EMAILREGISTERED","NAPAKA: E-mail naslov je e registriran");
define("_UUSERNAME","Uporabniko ime");
define("_FINISH","Konano");
define("_YOUUSEDEMAIL","Vi ali nekdo drugi je koristil Va e-mail");
define("_TOREGISTER","da registrira uporabniki raun na");
define("_FOLLOWINGMEM","Informacije o lanu:");
define("_UNICKNAME","-Nadimek:");
define("_UPASSWORD","-Geslo:");
define("_USERPASS4","Uporabniko geslo za");
define("_YOUAREREGISTERED","Sedaj ste registrirani. Najverjetneje ste e prejeli geslo na e-mail, vneene pri registraciji.");
define("_THISISYOURPAGE","To je vaa osebna stran");
define("_AVATAR","Simbol");
define("_WEBSITE","Web stran");
define("_ICQ","ICQ tevilka");
define("_AIM","AIM tevilka");
define("_YIM","YIM tevilka");
define("_MSNM","MSNM tevilka");
define("_LOCATION","Drava");
define("_OCCUPATION","Zanimanja");
define("_INTERESTS","Interesi");
define("_SIGNATURE","Podpis");
define("_MYHOMEPAGE","Moja stran:");
define("_MYEMAIL","Moj e-mail:");
define("_EXTRAINFO","Dodatne informacije");
define("_NOINFOFOR","Ni informacij za");
define("_LAST10COMMENTS","Zadnjih 10 komentara ki jih je poslal");
define("_LAST10SUBMISSIONS","Zadnjih 10 lankov ki jih je poslal");
define("_LOGININCOR","Napaka pri vstopu! Poizkusite ponovno...");
define("_USERLOGIN","Vstop za lane");
define("_USERREGLOGIN","Registracija/Vstop uporabnikov");
define("_REGNEWUSER","Registracija novega uporabnika");
define("_LIST","Popis");
define("_NEWUSER","Novi uporabnik");
define("_PASSWILLSEND","(Geslo bo poslana na navedeni naslov)");
define("_COOKIEWARNING","Opomba: Rauni so bazirani na cookijih (pikotkih).");
define("_ASREGUSER","Kot lan lahko:");
define("_ASREG1","Poiljate komentarje z lastnim imenom");
define("_ASREG2","Poiljate lanke z lastnim imenom");
define("_ASREG3","Imate oseben del na zaetni strani");
define("_ASREG4","Izbirate koliko lankov elite na zaetni strani");
define("_ASREG5","Spreminjate komentarje");
define("_ASREG6","Izbirate razliite teme");
define("_ASREG7","in e nekatere druge stvari...");
define("_REGISTERNOW","Registrirajte se! Brezplano je!");
define("_WEDONTGIVE","Nikoli ne bomo prodali niti dali drugim osebam Vaih osebnih informacij.");
define("_ALLOWEMAILVIEW","Dopustite drugi uporabnikom da vidijo moj e-mail naslov");
define("_OPTION","Opcija");
define("_PASSWORDLOST","Ste pozabili/izgubili geslo?");
define("_NOPROBLEM","Ni problem. Samo vpiite nadimek in kliknite na polji. Poslali Vam bomo avtomatski E-mail z 'potrdilnim geslom'. Tedaj morate ponovno vpisati nadimek in potrdilno geslo, nakar boste prejeli novo geslo.");
define("_CONFIRMATIONCODE","Potrdilno geslo");
define("_SENDPASSWORD","Polji geslo");
define("_YOUARELOGGEDOUT","Odjavljeni ste(logged out)!");
define("_SORRYNOUSERINFO","lan s tem nadimkom ni bil najden");
define("_USERACCOUNT","Uporabniki raun");
define("_AT","na");
define("_HASTHISEMAIL","ima ta e-mail.");
define("_AWEBUSERFROM","uporabnik iz");
define("_HASREQUESTED","je pravkar dal zahtevo da se mu polje geslo.");
define("_YOURNEWPASSWORD","Vae novo geslo je:");
define("_YOUCANCHANGE","Lahko spremenite po vstopu/prijavi na");
define("_IFYOUDIDNOTASK","e tega niste eleli ne skrbite. Tega sporoila ne vidi nihe razen Vas. e je to napaka, samo lepo vstopite z novih geslom.");
define("_UPDATEFAILED","Neuspeh pri spremembi. Prosimo obvestite administratorja.");
define("_PASSWORD4","Geslo za");
define("_MAILED","Poslano na mail.");
define("_CODEREQUESTED","je pravkar poslal zahtevo za potrdilno geslo.");
define("_YOURCODEIS","Vae potrdilno geslo je:");
define("_WITHTHISCODE","S tem geslom lahko izberete novo geslo na");
define("_IFYOUDIDNOTASK2","e tega niste eleli ne skrbite. Enostavno izbriite e-mail sporoilo.");
define("_CODEFOR","Potrdilno geslo za");
define("_USERPASSWORD4","Uporabniko geslo za");
define("_UREALNAME","Pravo ime");
define("_UREALEMAIL","Pravi e-mail");
define("_EMAILNOTPUBLIC","(To E-mail sporoilo ne bo javno, vendar je potrebno za poiljanje gesla)");
define("_UFAKEMAIL","Lani/javni E-mail");
define("_EMAILPUBLIC","(Ta E-mail bo javno objavljen. Napiite kar elite)");
define("_YOURHOMEPAGE","Vaa stran");
define("_YOURAVATAR","Va simbol");
define("_YICQ","Vaa ICQ tevilka");
define("_YAIM","Vaa AIM tevilka");
define("_YYIM","Vaa YIM tevilka");
define("_YMSNM","Vaa MSNM tevilka");
define("_YLOCATION","Vaa lokacija");
define("_YOCCUPATION","Va poklic");
define("_YINTERESTS","Vai interesi");
define("_255CHARMAX","(MAX 255 znakov. Podpis lahko vsebuje HTML oznake)");
define("_CANKNOWABOUT","(MAX 255 znakov. Napiite kar elite da drugi vedo o Vas)");
define("_TYPENEWPASSWORD","(vnesite novo geslo dva krat za spremembo)");
define("_SOMETHINGWRONG","Nekaj je zbrk***... sovrae to toliko kot je?");
define("_PASSDIFFERENT","Gesla sta razlina. Morata biti enaka.");
define("_CHARLONG","znakov");
define("_AVAILABLEAVATARS","Popis dostopnih simbolov");
define("_NEWSINHOME","tevilo lankov na zaetni strani");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","Aktiviraj osebno kazalo");
define("_CHECKTHISOPTION","(Oznaite to opcijo in sledei tekst se bo pojavil na zaetni strani)");
define("_YOUCANUSEHTML","(Lahko koristiti HTML za vpis povezav, npr)");
define("_SELECTTHEME","Izberi temo");
define("_THEMETEXT1","Ta opcija bo spremenila izgled cele strani.");
define("_THEMETEXT2","Spremembe bodo vidne samo Vam.");
define("_THEMETEXT3","Vsak uporabnik ima lahko svojo stran z temo po elji.");
define("_DISPLAYMODE","Prikai mod");
define("_SORTORDER","Vrstni red sortiranja");
define("_COMMENTSWILLIGNORED","Komentarji z oceno manjo od te postavke bodo ignorirani.");
define("_UNCUT","Uncut and Raw");
define("_EVERYTHING","Skoraj vse");
define("_FILTERMOSTANON","Filtriraj veinoma anonimno");
define("_USCORE","Ocena");
define("_SCORENOTE","Anonimni zaenjajo z ocenom 0, lani z 1. Moderatori dodajajo ali odvzemaju ocene.");
define("_NOSCORES","Ne prikazuj ocene");
define("_HIDDESCORES","(Skrite ocene: e vedno so v veljavi, samo vidite jih ne.)");
define("_MAXCOMMENT","Max dolina komentarja");
define("_TRUNCATES","(Razstavljanje dolgih komentarjev in dodajanje Preberi ve povezave. e se temu elite izogniti vpiite zares veliko tevilko)");
define("_BYTESNOTE","bytov (1024 bytov = 1K)");
define("_USENDPRIVATEMSG","Polji privatno sporoilo lanu");
define("_THEMESELECTION","Izbira teme");
define("_COMMENTSCONFIG","Konfiguracija komentarjev");
define("_HOMECONFIG","Konfiguracija zaetne strani");
define("_PERSONALINFO","Osebni podatki");
define("_USERSTATUS","Trenutni status uporabnikov");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","Spremenite svoje podatke");
define("_CONFIGCOMMENTS","Namestitev komentarjev");
define("_CHANGEHOME","Spremeni zaetno stran");
define("_LOGOUTEXIT","Izhod/Logout");
define("_SELECTTHETHEME","Izberi temo");
define("_PRIVATEMESSAGES","Vaa zasebna sporoila");
define("_EDITUSER","Uredi uporabnika");
define("_RECEIVENEWSLETTER","elite prejemati PISMO z novicami po e-mailu?");
define("_NOTSUBSCRIBED","Na nae Pismo z novicami niste naroeni");
define("_SUBSCRIBED","Vi ste naronik na nae Pismo z novicami");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Your_Account/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_YES","Da");
define("_NO","Ne");
define("_OPTIONAL","(po elji)");
define("_REQUIRED","(obvezno)");
define("_SAVECHANGES","Shrani spremembe");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","Brez komentarja");
define("_NESTED","Vgnezdeno");
define("_FLAT","Plosko");
define("_THREAD","Nit");
define("_OLDEST","Stareje");
define("_NEWEST","Noveje");
define("_HIGHEST","Z najvijim rezultatom");
define("_ERRORINVEMAIL","NAPAKA: Nepravilen E-mail");
define("_ERROREMAILSPACES","NAPAKA: E-mail naslov ne vsebuje razmakov");
define("_ERRORINVNICK","NAPAKA: Nepravilen nadimek");
define("_NICK2LONG","Nadimek je predolg. Biti mora manji od 25 znakov");
define("_NAMERESERVED","NAPAKA: To ime je rezervirano");
define("_NICKNOSPACES","NAPAKA: Nadimek ne sme vsebovati razmakov");
define("_NICKTAKEN","NAPAKA: Nadimek je e zaseden");
define("_EMAILREGISTERED","NAPAKA: E-mail naslov je e registriran");
define("_UUSERNAME","Uporabniko ime");
define("_FINISH","Konano");
define("_YOUUSEDEMAIL","Vi ali nekdo drugi je koristil Va e-mail");
define("_TOREGISTER","da registrira uporabniki raun na");
define("_FOLLOWINGMEM","Informacije o lanu:");
define("_UNICKNAME","-Nadimek:");
define("_UPASSWORD","-Geslo:");
define("_USERPASS4","Uporabniko geslo za");
define("_YOUAREREGISTERED","Sedaj ste registrirani. Najverjetneje ste e prejeli geslo na e-mail, vneene pri registraciji.");
define("_THISISYOURPAGE","To je vaa osebna stran");
define("_AVATAR","Simbol");
define("_WEBSITE","Web stran");
define("_ICQ","ICQ tevilka");
define("_AIM","AIM tevilka");
define("_YIM","YIM tevilka");
define("_MSNM","MSNM tevilka");
define("_LOCATION","Drava");
define("_OCCUPATION","Zanimanja");
define("_INTERESTS","Interesi");
define("_SIGNATURE","Podpis");
define("_MYHOMEPAGE","Moja stran:");
define("_MYEMAIL","Moj e-mail:");
define("_EXTRAINFO","Dodatne informacije");
define("_NOINFOFOR","Ni informacij za");
define("_LAST10COMMENTS","Zadnjih 10 komentara ki jih je poslal");
define("_LAST10SUBMISSIONS","Zadnjih 10 lankov ki jih je poslal");
define("_LOGININCOR","Napaka pri vstopu! Poizkusite ponovno...");
define("_USERLOGIN","Vstop za lane");
define("_USERREGLOGIN","Registracija/Vstop uporabnikov");
define("_REGNEWUSER","Registracija novega uporabnika");
define("_LIST","Popis");
define("_NEWUSER","Novi uporabnik");
define("_PASSWILLSEND","(Geslo bo poslana na navedeni naslov)");
define("_COOKIEWARNING","Opomba: Rauni so bazirani na cookijih (pikotkih).");
define("_ASREGUSER","Kot lan lahko:");
define("_ASREG1","Poiljate komentarje z lastnim imenom");
define("_ASREG2","Poiljate lanke z lastnim imenom");
define("_ASREG3","Imate oseben del na zaetni strani");
define("_ASREG4","Izbirate koliko lankov elite na zaetni strani");
define("_ASREG5","Spreminjate komentarje");
define("_ASREG6","Izbirate razliite teme");
define("_ASREG7","in e nekatere druge stvari...");
define("_REGISTERNOW","Registrirajte se! Brezplano je!");
define("_WEDONTGIVE","Nikoli ne bomo prodali niti dali drugim osebam Vaih osebnih informacij.");
define("_ALLOWEMAILVIEW","Dopustite drugi uporabnikom da vidijo moj e-mail naslov");
define("_OPTION","Opcija");
define("_PASSWORDLOST","Ste pozabili/izgubili geslo?");
define("_NOPROBLEM","Ni problem. Samo vpiite nadimek in kliknite na polji. Poslali Vam bomo avtomatski E-mail z 'potrdilnim geslom'. Tedaj morate ponovno vpisati nadimek in potrdilno geslo, nakar boste prejeli novo geslo.");
define("_CONFIRMATIONCODE","Potrdilno geslo");
define("_SENDPASSWORD","Polji geslo");
define("_YOUARELOGGEDOUT","Odjavljeni ste(logged out)!");
define("_SORRYNOUSERINFO","lan s tem nadimkom ni bil najden");
define("_USERACCOUNT","Uporabniki raun");
define("_AT","na");
define("_HASTHISEMAIL","ima ta e-mail.");
define("_AWEBUSERFROM","uporabnik iz");
define("_HASREQUESTED","je pravkar dal zahtevo da se mu polje geslo.");
define("_YOURNEWPASSWORD","Vae novo geslo je:");
define("_YOUCANCHANGE","Lahko spremenite po vstopu/prijavi na");
define("_IFYOUDIDNOTASK","e tega niste eleli ne skrbite. Tega sporoila ne vidi nihe razen Vas. e je to napaka, samo lepo vstopite z novih geslom.");
define("_UPDATEFAILED","Neuspeh pri spremembi. Prosimo obvestite administratorja.");
define("_PASSWORD4","Geslo za");
define("_MAILED","Poslano na mail.");
define("_CODEREQUESTED","je pravkar poslal zahtevo za potrdilno geslo.");
define("_YOURCODEIS","Vae potrdilno geslo je:");
define("_WITHTHISCODE","S tem geslom lahko izberete novo geslo na");
define("_IFYOUDIDNOTASK2","e tega niste eleli ne skrbite. Enostavno izbriite e-mail sporoilo.");
define("_CODEFOR","Potrdilno geslo za");
define("_USERPASSWORD4","Uporabniko geslo za");
define("_UREALNAME","Pravo ime");
define("_UREALEMAIL","Pravi e-mail");
define("_EMAILNOTPUBLIC","(To E-mail sporoilo ne bo javno, vendar je potrebno za poiljanje gesla)");
define("_UFAKEMAIL","Lani/javni E-mail");
define("_EMAILPUBLIC","(Ta E-mail bo javno objavljen. Napiite kar elite)");
define("_YOURHOMEPAGE","Vaa stran");
define("_YOURAVATAR","Va simbol");
define("_YICQ","Vaa ICQ tevilka");
define("_YAIM","Vaa AIM tevilka");
define("_YYIM","Vaa YIM tevilka");
define("_YMSNM","Vaa MSNM tevilka");
define("_YLOCATION","Vaa lokacija");
define("_YOCCUPATION","Va poklic");
define("_YINTERESTS","Vai interesi");
define("_255CHARMAX","(MAX 255 znakov. Podpis lahko vsebuje HTML oznake)");
define("_CANKNOWABOUT","(MAX 255 znakov. Napiite kar elite da drugi vedo o Vas)");
define("_TYPENEWPASSWORD","(vnesite novo geslo dva krat za spremembo)");
define("_SOMETHINGWRONG","Nekaj je zbrk***... sovrae to toliko kot je?");
define("_PASSDIFFERENT","Gesla sta razlina. Morata biti enaka.");
define("_CHARLONG","znakov");
define("_AVAILABLEAVATARS","Popis dostopnih simbolov");
define("_NEWSINHOME","tevilo lankov na zaetni strani");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","Aktiviraj osebno kazalo");
define("_CHECKTHISOPTION","(Oznaite to opcijo in sledei tekst se bo pojavil na zaetni strani)");
define("_YOUCANUSEHTML","(Lahko koristiti HTML za vpis povezav, npr)");
define("_SELECTTHEME","Izberi temo");
define("_THEMETEXT1","Ta opcija bo spremenila izgled cele strani.");
define("_THEMETEXT2","Spremembe bodo vidne samo Vam.");
define("_THEMETEXT3","Vsak uporabnik ima lahko svojo stran z temo po elji.");
define("_DISPLAYMODE","Prikai mod");
define("_SORTORDER","Vrstni red sortiranja");
define("_COMMENTSWILLIGNORED","Komentarji z oceno manjo od te postavke bodo ignorirani.");
define("_UNCUT","Uncut and Raw");
define("_EVERYTHING","Skoraj vse");
define("_FILTERMOSTANON","Filtriraj veinoma anonimno");
define("_USCORE","Ocena");
define("_SCORENOTE","Anonimni zaenjajo z ocenom 0, lani z 1. Moderatori dodajajo ali odvzemaju ocene.");
define("_NOSCORES","Ne prikazuj ocene");
define("_HIDDESCORES","(Skrite ocene: e vedno so v veljavi, samo vidite jih ne.)");
define("_MAXCOMMENT","Max dolina komentarja");
define("_TRUNCATES","(Razstavljanje dolgih komentarjev in dodajanje Preberi ve povezave. e se temu elite izogniti vpiite zares veliko tevilko)");
define("_BYTESNOTE","bytov (1024 bytov = 1K)");
define("_USENDPRIVATEMSG","Polji privatno sporoilo lanu");
define("_THEMESELECTION","Izbira teme");
define("_COMMENTSCONFIG","Konfiguracija komentarjev");
define("_HOMECONFIG","Konfiguracija zaetne strani");
define("_PERSONALINFO","Osebni podatki");
define("_USERSTATUS","Trenutni status uporabnikov");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","Spremenite svoje podatke");
define("_CONFIGCOMMENTS","Namestitev komentarjev");
define("_CHANGEHOME","Spremeni zaetno stran");
define("_LOGOUTEXIT","Izhod/Logout");
define("_SELECTTHETHEME","Izberi temo");
define("_PRIVATEMESSAGES","Vaa zasebna sporoila");
define("_EDITUSER","Uredi uporabnika");
define("_RECEIVENEWSLETTER","elite prejemati PISMO z novicami po e-mailu?");
define("_NOTSUBSCRIBED","Na nae Pismo z novicami niste naroeni");
define("_SUBSCRIBED","Vi ste naronik na nae Pismo z novicami");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>
